pub struct GoogleCloudDocumentaiV1beta2DocumentPageFormField {
pub corrected_key_text: Option<String>,
pub corrected_value_text: Option<String>,
pub field_name: Option<GoogleCloudDocumentaiV1beta2DocumentPageLayout>,
pub field_value: Option<GoogleCloudDocumentaiV1beta2DocumentPageLayout>,
pub name_detected_languages: Option<Vec<GoogleCloudDocumentaiV1beta2DocumentPageDetectedLanguage>>,
pub provenance: Option<GoogleCloudDocumentaiV1beta2DocumentProvenance>,
pub value_detected_languages: Option<Vec<GoogleCloudDocumentaiV1beta2DocumentPageDetectedLanguage>>,
pub value_type: Option<String>,
}Expand description
A form field detected on the page.
This type is not used in any activity, and only used as part of another schema.
Fields
corrected_key_text: Option<String>Created for Labeling UI to export key text. If corrections were made to the text identified by the field_name.text_anchor, this field will contain the correction.
corrected_value_text: Option<String>Created for Labeling UI to export value text. If corrections were made to the text identified by the field_value.text_anchor, this field will contain the correction.
field_name: Option<GoogleCloudDocumentaiV1beta2DocumentPageLayout>Layout for the FormField name. e.g. Address, Email, Grand total, Phone number, etc.
field_value: Option<GoogleCloudDocumentaiV1beta2DocumentPageLayout>Layout for the FormField value.
name_detected_languages: Option<Vec<GoogleCloudDocumentaiV1beta2DocumentPageDetectedLanguage>>A list of detected languages for name together with confidence.
provenance: Option<GoogleCloudDocumentaiV1beta2DocumentProvenance>The history of this annotation.
value_detected_languages: Option<Vec<GoogleCloudDocumentaiV1beta2DocumentPageDetectedLanguage>>A list of detected languages for value together with confidence.
value_type: Option<String>If the value is non-textual, this field represents the type. Current valid values are: - blank (this indicates the field_value is normal text) - unfilled_checkbox - filled_checkbox