pub struct GoogleCloudDocumentaiV1beta2DocumentPageLayout {
pub bounding_poly: Option<GoogleCloudDocumentaiV1beta2BoundingPoly>,
pub confidence: Option<f32>,
pub orientation: Option<String>,
pub text_anchor: Option<GoogleCloudDocumentaiV1beta2DocumentTextAnchor>,
}Expand description
Visual element describing a layout unit on a page.
This type is not used in any activity, and only used as part of another schema.
Fields
bounding_poly: Option<GoogleCloudDocumentaiV1beta2BoundingPoly>The bounding polygon for the Layout.
confidence: Option<f32>Confidence of the current Layout within context of the object this layout is for. e.g. confidence can be for a single token, a table, a visual element, etc. depending on context. Range [0, 1].
orientation: Option<String>Detected orientation for the Layout.
text_anchor: Option<GoogleCloudDocumentaiV1beta2DocumentTextAnchor>Text anchor indexing into the Document.text.