pub struct GoogleCloudDocumentaiV1beta2DocumentProvenance {
pub id: Option<i32>,
pub parents: Option<Vec<GoogleCloudDocumentaiV1beta2DocumentProvenanceParent>>,
pub revision: Option<i32>,
pub type_: Option<String>,
}Expand description
Structure to identify provenance relationships between annotations in different revisions.
This type is not used in any activity, and only used as part of another schema.
Fields
id: Option<i32>The Id of this operation. Needs to be unique within the scope of the revision.
parents: Option<Vec<GoogleCloudDocumentaiV1beta2DocumentProvenanceParent>>References to the original elements that are replaced.
revision: Option<i32>The index of the revision that produced this element.
type_: Option<String>The type of provenance operation.