pub struct GoogleCloudDocumentaiV1beta2DocumentRevisionHumanReview {
pub state: Option<String>,
pub state_message: Option<String>,
}Expand description
Human Review information of the document.
This type is not used in any activity, and only used as part of another schema.
Fields
state: Option<String>Human review state. e.g. requested, succeeded, rejected.
state_message: Option<String>A message providing more details about the current state of processing. For example, the rejection reason when the state is rejected.