pub struct GoogleCloudDocumentaiV1beta2DocumentTextAnchorTextSegment {
pub end_index: Option<i64>,
pub start_index: Option<i64>,
}Expand description
A text segment in the Document.text. The indices may be out of bounds which indicate that the text extends into another document shard for large sharded documents. See ShardInfo.text_offset
This type is not used in any activity, and only used as part of another schema.
Fields
end_index: Option<i64>TextSegment half open end UTF-8 char index in the Document.text.
start_index: Option<i64>TextSegment start UTF-8 char index in the Document.text.