pub struct GoogleCloudDocumentaiV1beta2GcsDestination {
pub uri: Option<String>,
}Expand description
The Google Cloud Storage location where the output file will be written to.
This type is not used in any activity, and only used as part of another schema.
Fields
uri: Option<String>no description provided