pub struct GoogleCloudDocumentaiV1beta2NormalizedVertex {
pub x: Option<f32>,
pub y: Option<f32>,
}Expand description
A vertex represents a 2D point in the image. NOTE: the normalized vertex coordinates are relative to the original image and range from 0 to 1.
This type is not used in any activity, and only used as part of another schema.
Fields
x: Option<f32>X coordinate.
y: Option<f32>Y coordinate (starts from the top of the image).