pub struct GoogleCloudDocumentaiV1beta2TableExtractionParams {
pub enabled: Option<bool>,
pub header_hints: Option<Vec<String>>,
pub model_version: Option<String>,
pub table_bound_hints: Option<Vec<GoogleCloudDocumentaiV1beta2TableBoundHint>>,
}Expand description
Parameters to control table extraction behavior.
This type is not used in any activity, and only used as part of another schema.
Fields
enabled: Option<bool>Whether to enable table extraction.
header_hints: Option<Vec<String>>Optional. Reserved for future use.
model_version: Option<String>Model version of the table extraction system. Default is “builtin/stable”. Specify “builtin/latest” for the latest model.
table_bound_hints: Option<Vec<GoogleCloudDocumentaiV1beta2TableBoundHint>>Optional. Table bounding box hints that can be provided to complex cases which our algorithm cannot locate the table(s) in.