pub struct GoogleCloudDocumentaiV1beta2Vertex {
pub x: Option<i32>,
pub y: Option<i32>,
}Expand description
A vertex represents a 2D point in the image. NOTE: the vertex coordinates are in the same scale as the original image.
This type is not used in any activity, and only used as part of another schema.
Fields
x: Option<i32>X coordinate.
y: Option<i32>Y coordinate (starts from the top of the image).