pub struct ProjectMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on project resources.
It is not used directly, but through the Document hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_documentai1_beta2 as documentai1_beta2;
use documentai1_beta2::{Document, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = Document::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `documents_batch_process(...)`, `documents_process(...)`, `locations_documents_batch_process(...)`, `locations_documents_process(...)`, `locations_operations_get(...)` and `operations_get(...)`
// to build up your call.
let rb = hub.projects();Implementations
Sourceimpl<'a, C> ProjectMethods<'a, C>
impl<'a, C> ProjectMethods<'a, C>
Sourcepub fn documents_batch_process(
&self,
request: GoogleCloudDocumentaiV1beta2BatchProcessDocumentsRequest,
parent: &str,
) -> ProjectDocumentBatchProcesCall<'a, C>
pub fn documents_batch_process( &self, request: GoogleCloudDocumentaiV1beta2BatchProcessDocumentsRequest, parent: &str, ) -> ProjectDocumentBatchProcesCall<'a, C>
Create a builder to help you perform the following task:
LRO endpoint to batch process many documents. The output is written to Cloud Storage as JSON in the Document format.
Arguments
request- No description provided.parent- Target project and location to make a call. Format:projects/{project-id}/locations/{location-id}. If no location is specified, a region will be chosen automatically.
Sourcepub fn documents_process(
&self,
request: GoogleCloudDocumentaiV1beta2ProcessDocumentRequest,
parent: &str,
) -> ProjectDocumentProcesCall<'a, C>
pub fn documents_process( &self, request: GoogleCloudDocumentaiV1beta2ProcessDocumentRequest, parent: &str, ) -> ProjectDocumentProcesCall<'a, C>
Create a builder to help you perform the following task:
Processes a single document.
Arguments
request- No description provided.parent- Target project and location to make a call. Format:projects/{project-id}/locations/{location-id}. If no location is specified, a region will be chosen automatically. This field is only populated when used in ProcessDocument method.
Sourcepub fn locations_documents_batch_process(
&self,
request: GoogleCloudDocumentaiV1beta2BatchProcessDocumentsRequest,
parent: &str,
) -> ProjectLocationDocumentBatchProcesCall<'a, C>
pub fn locations_documents_batch_process( &self, request: GoogleCloudDocumentaiV1beta2BatchProcessDocumentsRequest, parent: &str, ) -> ProjectLocationDocumentBatchProcesCall<'a, C>
Create a builder to help you perform the following task:
LRO endpoint to batch process many documents. The output is written to Cloud Storage as JSON in the Document format.
Arguments
request- No description provided.parent- Target project and location to make a call. Format:projects/{project-id}/locations/{location-id}. If no location is specified, a region will be chosen automatically.
Sourcepub fn locations_documents_process(
&self,
request: GoogleCloudDocumentaiV1beta2ProcessDocumentRequest,
parent: &str,
) -> ProjectLocationDocumentProcesCall<'a, C>
pub fn locations_documents_process( &self, request: GoogleCloudDocumentaiV1beta2ProcessDocumentRequest, parent: &str, ) -> ProjectLocationDocumentProcesCall<'a, C>
Create a builder to help you perform the following task:
Processes a single document.
Arguments
request- No description provided.parent- Target project and location to make a call. Format:projects/{project-id}/locations/{location-id}. If no location is specified, a region will be chosen automatically. This field is only populated when used in ProcessDocument method.
Sourcepub fn locations_operations_get(
&self,
name: &str,
) -> ProjectLocationOperationGetCall<'a, C>
pub fn locations_operations_get( &self, name: &str, ) -> ProjectLocationOperationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
Arguments
name- The name of the operation resource.
Sourcepub fn operations_get(&self, name: &str) -> ProjectOperationGetCall<'a, C>
pub fn operations_get(&self, name: &str) -> ProjectOperationGetCall<'a, C>
Create a builder to help you perform the following task:
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
Arguments
name- The name of the operation resource.