pub struct GoogleCloudDocumentaiV1beta2DocumentPageMatrix {
pub cols: Option<i32>,
pub data: Option<Vec<u8>>,
pub rows: Option<i32>,
pub type_: Option<i32>,
}Expand description
Representation for transformation matrix, intended to be compatible and used with OpenCV format for image manipulation.
This type is not used in any activity, and only used as part of another schema.
Fields
cols: Option<i32>Number of columns in the matrix.
data: Option<Vec<u8>>The matrix data.
rows: Option<i32>Number of rows in the matrix.
type_: Option<i32>This encodes information about what data type the matrix uses. For example, 0 (CV_8U) is an unsigned 8-bit image. For the full list of OpenCV primitive data types, please refer to https://docs.opencv.org/4.3.0/d1/d1b/group__core__hal__interface.html